#ifndef GET_TICKS_H
#define GET_TICKS_H

/*!
  \file
  \brief ԊԊu̎擾

  \author Satofumi KAMIMURA

  $Id$

  \todo monitor Ήɂ
*/

namespace beego {
  /*!
    \brief vO쎞Ԃ̎擾

    \return vO쎞 [msec]

    \attention ۂɂ́ASDL_Init() Ă΂Ă̎ԂƂȂB
  */
  extern size_t GetTicks(void);
};

#endif /* !GET_TICKS_H */
